==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectCallfunction.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectcallfunction_h
#define objectcallfunction_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_callfunction {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_function _function;
  int _function_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectFunction.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_callfunction_getuid (p_callfunction mycallfunction);
win32_interface gboolean adms_callfunction_cmp (p_callfunction mycallfunction,p_callfunction refcallfunction);
win32_interface p_callfunction adms_callfunction_new_1 (p_module mymodule,p_function myfunction);
#define adms_callfunction_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_callfunction_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_callfunction_new_impl (p_adms arguments[]);
win32_interface p_callfunction adms_callfunction_impl (void* member);
#define adms_callfunction(member) ((p_callfunction) (member))
#define adms_callfunction_new adms_callfunction_new_1
#define adms_callfunction_isdefault_module(callfunction) (adms_callfunction(callfunction)->_module_isdefault)
#define adms_callfunction_valueof_module(callfunction) (adms_callfunction(callfunction)->_module)
#define adms_callfunction_isdefault_function(callfunction) (adms_callfunction(callfunction)->_function_isdefault)
#define adms_callfunction_valueof_function(callfunction) (adms_callfunction(callfunction)->_function)
#define adms_callfunction_valueof_math(callfunction) ((p_math)callfunction)
#define adms_callfunction_valueof_adms(callfunction) ((p_adms)callfunction)
#define adms_callfunction_valueto_module(a,b) ((p_callfunction)a)->_module=(b)
win32_interface void adms_callfunction_valueto_module_impl (p_callfunction mycallfunction,p_module _module);
#define adms_callfunction_valueto_function(a,b) ((p_callfunction)a)->_function=(b)
win32_interface void adms_callfunction_valueto_function_impl (p_callfunction mycallfunction,p_function _function);
#endif /* objectcallfunction_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectCallfunction.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectcallfunction_h
#define objectcallfunction_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_callfunction {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_function _function;
  int _function_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectFunction.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_callfunction_uid (p_callfunction mycallfunction);
win32_interface int adms_callfunction_cmp (p_callfunction mycallfunction,p_callfunction refcallfunction);
win32_interface p_callfunction adms_callfunction_new(p_module mymodule,p_function myfunction);
win32_interface p_adms adms_callfunction_new_impl (p_adms arguments[]);
#define adms_callfunction(member) ((p_callfunction) (member))
#define adms_callfunction_isdefault_module(callfunction) (adms_callfunction(callfunction)->_module_isdefault)
#define adms_callfunction_valueof_module(callfunction) (adms_callfunction(callfunction)->_module)
#define adms_callfunction_isdefault_function(callfunction) (adms_callfunction(callfunction)->_function_isdefault)
#define adms_callfunction_valueof_function(callfunction) (adms_callfunction(callfunction)->_function)
#define adms_callfunction_valueof_math(callfunction) ((p_math)callfunction)
#define adms_callfunction_valueof_adms(callfunction) ((p_adms)callfunction)
win32_interface inline void adms_callfunction_valueto_module (p_callfunction mycallfunction,p_module _module);
win32_interface inline void adms_callfunction_valueto_function (p_callfunction mycallfunction,p_function _function);
win32_interface inline void adms_callfunction_free(p_callfunction mycallfunction);
#endif /* objectcallfunction_h */
